.. _glossary:

Glossary
========


.. glossary::
   :sorted:

   asyncio

      Reference implementation of :pep:`3156`

      See https://pypi.python.org/pypi/asyncio

   hiredis

      Python extension that wraps protocol parsing code in `hiredis`_.

      See https://pypi.python.org/pypi/hiredis

   error replies

      Redis server replies that start with - (minus) char.
      Usually starts with ``-ERR``.

   pytest

      A mature full-featured Python testing tool.
      See http://pytest.org/latest/

   uvloop

      Is an ultra fast implementation of asyncio event loop on top of libuv.
      See https://github.com/MagicStack/uvloop

.. _hiredis: https://github.com/redis/hiredis
